==> haskell-nanospec-0.2.2-385-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nanospec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nanospec
version:              0.2.2
visibility:           public
id:                   nanospec-0.2.2-Ct9SKZRHgjrAzFL1EKoz3y
key:                  nanospec-0.2.2-Ct9SKZRHgjrAzFL1EKoz3y
license:              MIT
copyright:            (c) 2012-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/nanospec#readme
synopsis:             A lightweight implementation of a subset of Hspec'\''s API
description:
    A lightweight implementation of a subset of Hspec'\''s API with minimal dependencies.

category:             Testing
abi:                  19bea62e62fc14852cb210ef795c9858
exposed-modules:      Test.Hspec
hidden-modules:       Paths_nanospec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/nanospec-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/nanospec-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/nanospec-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nanospec
hs-libraries:         HSnanospec-0.2.2-Ct9SKZRHgjrAzFL1EKoz3y
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-nanospec/html/nanospec.haddock
haddock-html:         /usr/share/doc/haskell-nanospec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nanospec-0.2.2-387-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nanospec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nanospec
version:              0.2.2
visibility:           public
id:                   nanospec-0.2.2-4biLQoG89zsKt6G2tcIkB9
key:                  nanospec-0.2.2-4biLQoG89zsKt6G2tcIkB9
license:              MIT
copyright:            (c) 2012-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/nanospec#readme
synopsis:             A lightweight implementation of a subset of Hspec'\''s API
description:
    A lightweight implementation of a subset of Hspec'\''s API with minimal dependencies.

category:             Testing
abi:                  718ec189182b3edc02a9711e3dc659dd
exposed-modules:      Test.Hspec
hidden-modules:       Paths_nanospec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/nanospec-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/nanospec-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/nanospec-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nanospec
hs-libraries:         HSnanospec-0.2.2-4biLQoG89zsKt6G2tcIkB9
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-nanospec/html/nanospec.haddock
haddock-html:         /usr/share/doc/haskell-nanospec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
